
<h1>WeightLogger</h1>
<h3>A simple app to monitor personal fitness.</h3>
<br>

![demo](https://github.com/fayefv/weightlogger/blob/master/demo.png?raw=true)

<p> User may record body weight by selecting 
or entering a calendar date.  Body weight
is plotted over all time or just the 
previous week.</p>
<br>
<p>Future improvements may include more
advanced statistics in the trends section.</p>

